spannertools.Spanner
====================

.. inheritance-diagram:: abjad.tools.spannertools.Spanner.Spanner.Spanner
   :private-bases:

.. autoclass:: abjad.tools.spannertools.Spanner.Spanner.Spanner

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.components

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.duration_in_seconds

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.leaves

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.offset

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.override

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.preprolated_duration

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.prolated_duration

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.set

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.written_duration

Methods
-------

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.append

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.append_left

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.clear

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.extend

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.extend_left

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.fracture

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.fuse

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.index

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.pop

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.pop_left

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__contains__

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__getitem__

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__len__

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__lt__

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__repr__

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__str__

   .. note:: Inherited from `__builtin__.object`
